File - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# File

A `betty.ancestry.File` describes a file, such as an image or a PDF document, that is attached to other entities.

## Fields

Files inherit from:

- Privacy

`citations` (iterable of Citation)

  The citations for this file.

`description` (optional Static translations)

  The event’s human-readable description.

`entities` (iterable of any entity)

  The entities this file is attached to.

`id` (`str`)

  The file’s own entity ID.

`links` (iterable of Link)

  The external links for this file.

`notes` (iterable of Note)

  The notes for this file.

`media_type` (MediaType)

  The media type of this file.